diff --git a/Modules/Applications/AppClassification/app/otbSampleAugmentation.cxx b/Modules/Applications/AppClassification/app/otbSampleAugmentation.cxx
index ab00897140677984a2850257a0d70475a052e93d..9749a9f4c4aa67c2b4fe7d6c290a31b7fc9a440f 100644
--- a/Modules/Applications/AppClassification/app/otbSampleAugmentation.cxx
+++ b/Modules/Applications/AppClassification/app/otbSampleAugmentation.cxx
@@ -116,7 +116,7 @@ private:
                             "The noise added to the input samples will have the "
                             "standard deviation of the input features divided "
                             "by the value of this parameter. ");
-    SetDefaultParameterFloat("strategy.jitter.stdfactor",10000);
+    SetDefaultParameterFloat("strategy.jitter.stdfactor",10);
 
     AddChoice("strategy.smote","Smote input samples");
     SetParameterDescription("strategy.smote","The new samples are generated "
diff --git a/Modules/Learning/Sampling/include/otbSampleAugmentation.h b/Modules/Learning/Sampling/include/otbSampleAugmentation.h
index 40f62d0cb8a83472e30832ec10096f93c9af9ba3..f562a636e616a53c35cb94a30b59e95d7558dc3e 100644
--- a/Modules/Learning/Sampling/include/otbSampleAugmentation.h
+++ b/Modules/Learning/Sampling/include/otbSampleAugmentation.h
@@ -85,13 +85,13 @@ void replicateSamples(const SampleVectorType& inSamples,
 /** Create new samples by adding noise to existing samples. Gaussian
 * noise is added to randomly selected samples. The standard deviation
 * of the noise added to each component is the same as the one of the
 * input variables multiplied by stdFactor (defaults to 1). The
 * elements of newSamples are removed before proceeding.
 */
 void jitterSamples(const SampleVectorType& inSamples, 
                    const size_t nbSamples,
                       SampleVectorType& newSamples,
-                   float stdFactor=10000,
+                   float stdFactor=10,
                    const int seed = std::time(nullptr))
 {
   newSamples.resize(nbSamples);
@@ -85,13 +85,13 @@ void replicateSamples(const SampleVectorType& inSamples,
 * noise is added to randomly selected samples. The standard deviation
 * of the noise added to each component is the same as the one of the
-* input variables multiplied by stdFactor (defaults to 1). The
+* input variables divided by stdFactor (defaults to 10). The
 * elements of newSamples are removed before proceeding.
 */